@@ -1,8 +1,22 @@
 from pydantic import BaseModel, Field
 from typing import Annotated, Generic, TypeVar
+from maleo.types.integer import DoubleInts
 from maleo.types.misc import StrOrStrEnumT
 
 
+class ImageSize(BaseModel):
+    height: Annotated[int, Field(..., description="Height", ge=0)]
+    width: Annotated[int, Field(..., description="Width", ge=0)]
+
+    @property
+    def shape(self) -> DoubleInts:
+        return (self.height, self.width)
+
+    @classmethod
+    def from_shape(cls, shape: DoubleInts) -> "ImageSize":
+        return cls(height=shape[0], width=shape[1])
+
+
 class BoundingBox(BaseModel):
     x_min: Annotated[float, Field(0.0, description="X Min", ge=0.0)]
     y_min: Annotated[float, Field(0.0, description="Y Min", ge=0.0)]
