@@ -1,5 +1,5 @@
 from maleo.schemas.resource import Resource, ResourceIdentifier
-from maleo.types.string import SequenceOfStrings
+from maleo.types.string import SeqOfStrs
 
 
 XRAY_RESOURCE = Resource(
@@ -8,7 +8,7 @@ XRAY_RESOURCE = Resource(
 )
 
 
-VALID_EXTENSIONS: SequenceOfStrings = [
+VALID_EXTENSIONS: SeqOfStrs = [
     ".dcm",
     ".dicom",
     ".jpeg",
@@ -17,7 +17,7 @@ VALID_EXTENSIONS: SequenceOfStrings = [
 ]
 
 
-VALID_MIME_TYPES: SequenceOfStrings = [
+VALID_MIME_TYPES: SeqOfStrs = [
     "application/dcm",
     "application/dicom",
     "image/jpeg",
