@@ -37,7 +37,7 @@ MULTI_FINDING_CLASSES: SequenceOfMultiFindingClasses = [
 
 INFERENCE_RESOURCE = deepcopy(XRAY_RESOURCE)
 INFERENCE_RESOURCE.identifiers.append(
-    ResourceIdentifier(key="inferences", name="Inferences", slug="inferences")
+    ResourceIdentifier(key="inference", name="Inference", slug="inferences")
 )
 
 
