@@ -18,5 +18,5 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: dict[
 
 RECORD_RESOURCE = deepcopy(XRAY_RESOURCE)
 RECORD_RESOURCE.identifiers.append(
-    ResourceIdentifier(key="records", name="Records", slug="records")
+    ResourceIdentifier(key="record", name="Record", slug="records")
 )
