@@ -19,6 +19,6 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: dict[
 RECORD_INFERENCE_RESOURCE = deepcopy(XRAY_RESOURCE)
 RECORD_INFERENCE_RESOURCE.identifiers.append(
     ResourceIdentifier(
-        key="records_inferences", name="Records Inferences", slug="records-inferences"
+        key="record_inference", name="Record Inference", slug="records-inferences"
     )
 )
