@@ -6,7 +6,7 @@ from maleo.enums.identity import Gender
 from maleo.enums.medical import MedicalService
 from maleo.enums.status import DataStatus as DataStatusEnum, SimpleDataStatusMixin
 from maleo.schemas.mixins.identity import DataIdentifier
-from maleo.schemas.mixins.timestamp import DataTimestamp
+from maleo.schemas.mixins.timestamp import LifecycleTimestamp
 from maleo.types.any import ListOfAny
 from maleo.types.string import OptStr
 from maleo.types.uuid import OptUUID
@@ -15,7 +15,7 @@ from .enums.inference import InferenceType
 
 class RecordCoreDTO(
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     organization_id: Annotated[OptUUID, Field(None, description="Organization ID")] = (
@@ -40,7 +40,7 @@ class RecordCoreDTOMixin(BaseModel):
 
 class InferenceCoreDTO(
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     organization_id: Annotated[OptUUID, Field(None, description="Organization ID")] = (
@@ -65,7 +65,7 @@ class InferenceCoreDTOMixin(BaseModel):
 class RecordInferenceDTO(
     InferenceCoreDTOMixin,
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
@@ -85,7 +85,7 @@ class RecordCompleteDTO(RecordInferencesDTOMixin, RecordCoreDTO):
 class InferenceRecordDTO(
     RecordCoreDTOMixin,
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
@@ -106,7 +106,7 @@ class RecordAndInferenceDTO(
     InferenceCoreDTOMixin,
     RecordCoreDTOMixin,
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
