@@ -11,6 +11,10 @@ class IdentifierType(StrEnum):
     def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
+    @property
+    def column(self) -> str:
+        return self.value
+
 
 class InferenceType(StrEnum):
     MULTI_FINDING = "multi_finding"
