@@ -13,7 +13,7 @@ from maleo.enums.identity import Gender
 from maleo.enums.medical import MedicalService
 from maleo.enums.status import DataStatus as DataStatusEnum, SimpleDataStatusMixin
 from maleo.schemas.mixins.identity import DataIdentifier
-from maleo.schemas.mixins.timestamp import DataTimestamp
+from maleo.schemas.mixins.timestamp import LifecycleTimestamp
 from maleo.types.string import OptStr
 from maleo.types.uuid import OptUUID
 from ...schemas import FindingWithoutBox, FindingWithBox
@@ -39,7 +39,7 @@ AnyXrayFindingT = TypeVar("AnyXrayFindingT", bound=AnyXrayFinding)
 
 class RecordCoreSchema(
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     organization_id: Annotated[OptUUID, Field(None, description="Organization ID")] = (
@@ -65,7 +65,7 @@ class RecordCoreSchemaMixin(BaseModel):
 
 class GenericInferenceCoreSchema(
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
     Generic[InferenceTypeT, AnyXrayFindingT],
 ):
@@ -170,7 +170,7 @@ class InferenceCoreSchemaMixin(BaseModel, Generic[AnyInferenceCoreSchemaT]):
 class RecordInferenceSchema(
     InferenceCoreSchemaMixin[AnyInferenceCoreSchema],
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
@@ -190,7 +190,7 @@ class RecordCompleteSchema(RecordInferencesSchemaMixin, RecordCoreSchema):
 class InferenceRecordSchema(
     RecordCoreSchemaMixin,
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
@@ -256,7 +256,7 @@ class RecordAndInferenceSchema(
     InferenceCoreSchemaMixin[AnyInferenceCoreSchema],
     RecordCoreSchemaMixin,
     SimpleDataStatusMixin[DataStatusEnum],
-    DataTimestamp,
+    LifecycleTimestamp,
     DataIdentifier,
 ):
     pass
