@@ -42,7 +42,7 @@ from ..enums.inference import (
     InferenceTypeT,
     OptionalListOfInferenceTypes,
 )
-from ..mixins.inference import InferenceTypes
+from ..mixins.inference import InferenceTypes, InferenceIdentifier
 from ..types.inference import IdentifierValueType
 
 
@@ -197,7 +197,16 @@ class ReadMultipleParameter(
         return params
 
 
-class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValueType]):
+class ReadSingleParameter(BaseReadSingleParameter[InferenceIdentifier]):
+    @classmethod
+    def from_identifier(
+        cls,
+        identifier: InferenceIdentifier,
+        statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter":
+        return cls(identifier=identifier, statuses=statuses, use_cache=use_cache)
+
     @overload
     @classmethod
     def new(
@@ -216,6 +225,15 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
@@ -225,8 +243,9 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier_type=identifier_type,
-            identifier_value=identifier_value,
+            identifier=InferenceIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
             statuses=statuses,
             use_cache=use_cache,
         )
