@@ -23,13 +23,14 @@ from maleo.enums.status import (
 )
 from maleo.schemas.mixins.filter import convert as convert_filter
 from maleo.schemas.mixins.identity import (
-    IdentifierTypeValue,
+    IdentifierMixin,
     Ids,
     UUIDs,
     UUIDOrganizationIds,
     UUIDUserIds,
 )
 from maleo.schemas.mixins.sort import convert as convert_sort
+from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
 from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
@@ -42,6 +43,7 @@ from maleo.types.integer import OptListOfInts
 from maleo.types.string import OptStr
 from maleo.types.uuid import OptListOfUUIDs, OptUUID
 from ..enums.record import IdentifierType
+from ..mixins.record import RecordIdentifier
 from ..types.record import IdentifierValueType
 
 
@@ -136,7 +138,16 @@ class ReadMultipleParameter(
         return params
 
 
-class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValueType]):
+class ReadSingleParameter(BaseReadSingleParameter[RecordIdentifier]):
+    @classmethod
+    def from_identifier(
+        cls,
+        identifier: RecordIdentifier,
+        statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter":
+        return cls(identifier=identifier, statuses=statuses, use_cache=use_cache)
+
     @overload
     @classmethod
     def new(
@@ -155,6 +166,15 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
@@ -164,8 +184,7 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier_type=identifier_type,
-            identifier_value=identifier_value,
+            identifier=RecordIdentifier(type=identifier_type, value=identifier_value),
             statuses=statuses,
             use_cache=use_cache,
         )
@@ -203,22 +222,106 @@ class UpdateDataMixin(BaseModel, Generic[UpdateDataT]):
 
 class UpdateParameter(
     UpdateDataMixin[UpdateDataT],
-    IdentifierTypeValue[
-        IdentifierType,
-        IdentifierValueType,
-    ],
+    IdentifierMixin[RecordIdentifier],
     Generic[UpdateDataT],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter":
+        return cls(
+            identifier=RecordIdentifier(type=identifier_type, value=identifier_value),
+            data=data,
+        )
 
 
 class StatusUpdateParameter(
-    BaseStatusUpdateParameter,
+    BaseStatusUpdateParameter[RecordIdentifier],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter":
+        return cls(
+            identifier=RecordIdentifier(type=identifier_type, value=identifier_value),
+            type=type,
+        )
 
 
-class DeleteSingleParameter(
-    BaseDeleteSingleParameter[IdentifierType, IdentifierValueType]
-):
-    pass
+class DeleteSingleParameter(BaseDeleteSingleParameter[RecordIdentifier]):
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.ID], identifier_value: int
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.UUID], identifier_value: UUID
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter": ...
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter":
+        return cls(
+            identifier=RecordIdentifier(type=identifier_type, value=identifier_value)
+        )
